ObjectValidator class

Inheritance

Constructors

ObjectValidator({String? fieldName, required ObjectValidatorValidateFunction validateFunction, ObjectValidatorErrorMessageBuilder? errorMessageBuilder})
const

Properties

defaultErrorMessage → String
default error message when errorMessage value is null
no setteroverride
errorMessage → String
get error message
no setterinherited
errorMessageBuilder → ObjectValidatorErrorMessageBuilder?
final
fieldName → String?
field name
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String
decorator name
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validateFunction → ObjectValidatorValidateFunction
final

Methods

isValid(dynamic value) → bool
implement this function to validate value
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate(dynamic value) → String?
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited