ValidationError class

Implemented types
Available extensions

Constructors

ValidationError({required String fieldName, required dynamic originalValue, required String errorMessage})

Properties

errorMessage → String
final
fieldName → String
final
formattedMessage → String

Available on Exception, provided by the ExceptionExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
originalValue → dynamic
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited